@@ -111,12 +111,13 @@ def on_celery_import_modules(*args, **kwargs):
 
     import airflow.jobs.local_task_job_runner
     import airflow.macros
-    import airflow.operators.python
 
     try:
         import airflow.providers.standard.operators.bash
+        import airflow.providers.standard.operators.python
     except ImportError:
-        import airflow.operators.bash  # noqa: F401
+        import airflow.operators.bash
+        import airflow.operators.python  # noqa: F401
 
     with contextlib.suppress(ImportError):
         import numpy  # noqa: F401
